@@ -59,7 +59,7 @@ DeclarationPointer ExpressionVisitor::processVariable(VariableIdentifierAst* var
     DeclarationPointer ret;
     Identifier identifier = identifierForNode(variable).last();
 
-    ifDebug(kDebug() << "processing variable" << identifier.toString() << position.textCursor();)
+    ifDebug(kDebug() << "processing variable" << identifier.toString() << position.castToSimpleCursor();)
 
     if (identifier.nameEquals(Identifier("this"))) {
         DUChainReadLocker lock(DUChain::lock());
@@ -115,8 +115,12 @@ DeclarationPointer ExpressionVisitor::processVariable(VariableIdentifierAst* var
     }
     if ( !m_isAssignmentExpressionEqual || identifier.nameEquals( Identifier("this") )
          // might be something like $s = $s . $s; in which case we have to add a use for the first $s
-         || (ret && ret->range().end < position) ) {
-        usingDeclaration(variable, ret);
+         || (ret && ret->range().end < position) )
+    {
+        // also don't report uses for the place of declaration
+        if (!ret || ret->range().end != position) {
+            usingDeclaration(variable, ret);
+        }
     }
     ifDebug(kDebug() << "found declaration:" << (ret ? ret->toString() : QString("no declaration found"));)
     return ret;
@@ -732,7 +736,7 @@ DeclarationPointer ExpressionVisitor::findDeclarationImport(DeclarationType decl
 
 DeclarationPointer ExpressionVisitor::findDeclarationImport( DeclarationType declarationType, AstNode* node, const QualifiedIdentifier& identifier)
 {
-    return findDeclarationImportHelper(m_currentContext, identifier, declarationType, node, m_editor);
+    return findDeclarationImportHelper(m_currentContext, identifier, declarationType);
 }
 
 }
