@@ -101,6 +101,7 @@ private slots:
     void foreachIterator();
     void foreachIterator2();
     void foreachIterator3();
+    void foreachIterator4();
     void returnThis();
     void unsureReturnType();
     void unsureReturnType2();
@@ -126,6 +127,7 @@ private slots:
     void namespacesNoCurly();
     void useNamespace();
     void namespaceStaticVar();
+    void namespacedCatch();
     void errorRecovery_data();
     void errorRecovery();
     void varStatic();
